@@ -20,7 +20,7 @@ class MapFunctions(object):
         # objects needed
         spc = space.SpaceTransform(central, linear, planar)
         gm = grid.GridMaker()
-        itrp = near.Nearest(self.mobj.values,self.mobj.F,self.mobj.M,self.mobj.S) 
+        itrp = near.Nearest(self.mobj.values,self.mobj.F,self.mobj.M,self.mobj.S, log_level=1) 
         #########                                        
         u_coords = gm.get_unit_grid(width,samples)        
         xyz_coords = spc.get_coords(u_coords)
